@@ -32,9 +32,7 @@ from typing import Any
 
 import jsonpickle
 
-from metrics.core.constants import XP_WARE_NAME, CAMPAIGN_NAME, CAMPAIGN_TIMEOUT, CAMPAIGN_MEMOUT, CAMPAIGN_XP_WARES, \
-    CAMPAIGN_INPUT_SET, CAMPAIGN_EXPERIMENTS, EXPERIMENT_INPUT, EXPERIMENT_XP_WARE, EXPERIMENT_CPU_TIME, INPUT_NAME, \
-    INPUT_SET_NAME, INPUT_SET_INPUTS
+from metrics.core.constants import *
 
 """
 Global campaign attribute constants
@@ -111,6 +109,14 @@ class Campaign(Model):
         """
         return self.input_set
 
+    def get_experiment_ware_names(self):
+        """
+
+        @return:
+        """
+        return [ew.name for ew in self.experiment_wares]
+
+
 class Experiment(Model):
     """
     This model corresponds to an experiment.
@@ -160,4 +166,11 @@ class InputSet(Model):
 
         @return:
         """
-        return self.inputs
\ No newline at end of file
+        return self.inputs
+
+    def get_input_names(self):
+        """
+
+        @return:
+        """
+        return [inp.name for inp in self.inputs]
